==> openshift-model-miscellaneous-6.5.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/HardwareSystemVendorFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HardwareSystemVendorFluentImpl<A extends HardwareSystemVendorFluent<A>> extends BaseFluent<A> implements HardwareSystemVendorFluent<A>{
  public HardwareSystemVendorFluentImpl() {
  }
  public HardwareSystemVendorFluentImpl(HardwareSystemVendor instance) {
    this.withManufacturer(instance.getManufacturer()); 
    this.withProductName(instance.getProductName()); 
    this.withSerialNumber(instance.getSerialNumber()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String manufacturer;
  private String productName;
  private String serialNumber;
  private Map<String,Object> additionalProperties;
  public String getManufacturer() {
    return this.manufacturer;
  }
  public A withManufacturer(String manufacturer) {
    this.manufacturer=manufacturer; return (A) this;
  }
  public Boolean hasManufacturer() {
    return this.manufacturer != null;
  }
  public String getProductName() {
    return this.productName;
  }
  public A withProductName(String productName) {
    this.productName=productName; return (A) this;
  }
  public Boolean hasProductName() {
    return this.productName != null;
  }
  public String getSerialNumber() {
    return this.serialNumber;
  }
  public A withSerialNumber(String serialNumber) {
    this.serialNumber=serialNumber; return (A) this;
  }
  public Boolean hasSerialNumber() {
    return this.serialNumber != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HardwareSystemVendorFluentImpl that = (HardwareSystemVendorFluentImpl) o;
    if (manufacturer != null ? !manufacturer.equals(that.manufacturer) :that.manufacturer != null) return false;
    if (productName != null ? !productName.equals(that.productName) :that.productName != null) return false;
    if (serialNumber != null ? !serialNumber.equals(that.serialNumber) :that.serialNumber != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(manufacturer,  productName,  serialNumber,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (manufacturer != null) { sb.append("manufacturer:"); sb.append(manufacturer + ","); }
    if (productName != null) { sb.append("productName:"); sb.append(productName + ","); }
    if (serialNumber != null) { sb.append("serialNumber:"); sb.append(serialNumber + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-miscellaneous-6.7.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/HardwareSystemVendorFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HardwareSystemVendorFluentImpl<A extends HardwareSystemVendorFluent<A>> extends BaseFluent<A> implements HardwareSystemVendorFluent<A>{
  public HardwareSystemVendorFluentImpl() {
  }
  public HardwareSystemVendorFluentImpl(HardwareSystemVendor instance) {
    if (instance != null) {
      this.withManufacturer(instance.getManufacturer());
      this.withProductName(instance.getProductName());
      this.withSerialNumber(instance.getSerialNumber());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String manufacturer;
  private String productName;
  private String serialNumber;
  private Map<String,Object> additionalProperties;
  public String getManufacturer() {
    return this.manufacturer;
  }
  public A withManufacturer(String manufacturer) {
    this.manufacturer=manufacturer; return (A) this;
  }
  public Boolean hasManufacturer() {
    return this.manufacturer != null;
  }
  public String getProductName() {
    return this.productName;
  }
  public A withProductName(String productName) {
    this.productName=productName; return (A) this;
  }
  public Boolean hasProductName() {
    return this.productName != null;
  }
  public String getSerialNumber() {
    return this.serialNumber;
  }
  public A withSerialNumber(String serialNumber) {
    this.serialNumber=serialNumber; return (A) this;
  }
  public Boolean hasSerialNumber() {
    return this.serialNumber != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HardwareSystemVendorFluentImpl that = (HardwareSystemVendorFluentImpl) o;
    if (!java.util.Objects.equals(manufacturer, that.manufacturer)) return false;

    if (!java.util.Objects.equals(productName, that.productName)) return false;

    if (!java.util.Objects.equals(serialNumber, that.serialNumber)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(manufacturer,  productName,  serialNumber,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (manufacturer != null) { sb.append("manufacturer:"); sb.append(manufacturer + ","); }
    if (productName != null) { sb.append("productName:"); sb.append(productName + ","); }
    if (serialNumber != null) { sb.append("serialNumber:"); sb.append(serialNumber + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
